Documentation
¶
Overview ¶
Package v1 contains API Schema definitions for the webapp v1 API group +kubebuilder:object:generate=true +groupName=keikoproj.io
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "keikoproj.io", Version: "v1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type FlippyCondition ¶
type FlippyCondition struct {
//Kubernetes Object
K8S K8S `json:"K8S,omitempty"`
//Status to be verified
Status string `json:"Status,omitempty"`
//Retry configuration for status check
StatusCheckConfig StatusCheckConfig `json:"StatusCheckConfig,omitempty"`
}
func (*FlippyCondition) DeepCopy ¶
func (in *FlippyCondition) DeepCopy() *FlippyCondition
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlippyCondition.
func (*FlippyCondition) DeepCopyInto ¶
func (in *FlippyCondition) DeepCopyInto(out *FlippyCondition)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FlippyConfig ¶
type FlippyConfig struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec FlippyConfigSpec `json:"spec,omitempty"`
Status FlippyConfigStatus `json:"status,omitempty"`
}
FlippyConfig is the Schema for the FlippyConfig API
func (*FlippyConfig) DeepCopy ¶
func (in *FlippyConfig) DeepCopy() *FlippyConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlippyConfig.
func (*FlippyConfig) DeepCopyInto ¶
func (in *FlippyConfig) DeepCopyInto(out *FlippyConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*FlippyConfig) DeepCopyObject ¶
func (in *FlippyConfig) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FlippyConfigList ¶
type FlippyConfigList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []FlippyConfig `json:"items"`
}
FlippyConfigList contains a list of FlippyConfig
func (*FlippyConfigList) DeepCopy ¶
func (in *FlippyConfigList) DeepCopy() *FlippyConfigList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlippyConfigList.
func (*FlippyConfigList) DeepCopyInto ¶
func (in *FlippyConfigList) DeepCopyInto(out *FlippyConfigList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*FlippyConfigList) DeepCopyObject ¶
func (in *FlippyConfigList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type FlippyConfigSpec ¶
type FlippyConfigSpec struct {
//List of allowed docker images
ImageList []string `json:"ImageList,omitempty"`
//List of precondition before rotating any pod
Preconditions []FlippyCondition `json:"Preconditions,omitempty"`
//List of conditions on which pods get filter
ProcessFilter ProcessFilter `json:"ProcessFilter,omitempty"`
RestartObjects []RestartObject `json:"RestartObjects,omitempty"`
PostFilterRestarts []FlippyCondition `json:"PostFilterRestarts,omitempty"`
}
FlippyConfigSpec defines the desired state of FlippyConfig
func (*FlippyConfigSpec) DeepCopy ¶
func (in *FlippyConfigSpec) DeepCopy() *FlippyConfigSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlippyConfigSpec.
func (*FlippyConfigSpec) DeepCopyInto ¶
func (in *FlippyConfigSpec) DeepCopyInto(out *FlippyConfigSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type FlippyConfigStatus ¶
type FlippyConfigStatus struct {
}
FlippyConfigStatus defines the observed state of FlippyConfig
func (*FlippyConfigStatus) DeepCopy ¶
func (in *FlippyConfigStatus) DeepCopy() *FlippyConfigStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FlippyConfigStatus.
func (*FlippyConfigStatus) DeepCopyInto ¶
func (in *FlippyConfigStatus) DeepCopyInto(out *FlippyConfigStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type K8S ¶
type K8S struct {
//Type of object. E.g Deployment
Type string `json:"Type,omitempty"`
//Name of the object
Name string `json:"Name,omitempty"`
//Namespace it belongs
Namespace string `json:"Namespace,omitempty"`
}
func (*K8S) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new K8S.
func (*K8S) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ProcessFilter ¶
type ProcessFilter struct {
//Metdata Pod Label Filter
PodLabels map[string]string `json:"PodLabels,omitempty"`
//Metdata Namespace Label Filter
NamespaceLabels map[string]string `json:"Labels,omitempty"`
//List of annotation on object eg. Deployment ArgoRollouts
Annotations map[string]string `json:"Annotations,omitempty"`
//Container names
Containers []string `json:"Containers,omitempty"`
PreProcessRestart K8S `json:"PreProcessRestart,omitempty"`
}
func (*ProcessFilter) DeepCopy ¶
func (in *ProcessFilter) DeepCopy() *ProcessFilter
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ProcessFilter.
func (*ProcessFilter) DeepCopyInto ¶
func (in *ProcessFilter) DeepCopyInto(out *ProcessFilter)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RestartObject ¶
type RestartObject struct {
//Type of object to be restarted
Type string `json:"Type,omitempty"`
//Retry configuration for status check
StatusCheckConfig StatusCheckConfig `json:"StatusCheckConfig,omitempty"`
}
func (*RestartObject) DeepCopy ¶
func (in *RestartObject) DeepCopy() *RestartObject
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RestartObject.
func (*RestartObject) DeepCopyInto ¶
func (in *RestartObject) DeepCopyInto(out *RestartObject)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type StatusCheckConfig ¶
type StatusCheckConfig struct {
//CheckStatus after
CheckStatus bool `json:"CheckStatus,omitempty"`
//Retries to check status
MaxRetry int `json:"MaxRetry,omitempty"`
//Retry duration in seconds
RetryDuration int `json:"RetryDuration,omitempty"`
}
func (*StatusCheckConfig) DeepCopy ¶
func (in *StatusCheckConfig) DeepCopy() *StatusCheckConfig
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StatusCheckConfig.
func (*StatusCheckConfig) DeepCopyInto ¶
func (in *StatusCheckConfig) DeepCopyInto(out *StatusCheckConfig)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.